summaryrefslogtreecommitdiffstats
path: root/src/exceptions
diff options
context:
space:
mode:
authorKore Nordmann <github@kore-nordmann.de>2006-11-30 08:44:35 +0000
committerKore Nordmann <github@kore-nordmann.de>2006-11-30 08:44:35 +0000
commit900e04fff3c7ef75917bcb6b039f71f817774702 (patch)
treee53ff028184a59fbcb519bf6a9b002b1305de1c0 /src/exceptions
parentdb9085af71795942fac7ce7e7675b0891ed354ba (diff)
downloadzetacomponents-graph-900e04fff3c7ef75917bcb6b039f71f817774702.zip
zetacomponents-graph-900e04fff3c7ef75917bcb6b039f71f817774702.tar.gz
- Resolved: Issue #9543 (Rename Ming driver to Flash in the Graph component)
Diffstat (limited to 'src/exceptions')
-rw-r--r--src/exceptions/flash_bitmap_boundings.php (renamed from src/exceptions/ming_bitmap_boundings.php)8
-rw-r--r--src/exceptions/flash_bitmap_type.php (renamed from src/exceptions/ming_bitmap_type.php)8
2 files changed, 8 insertions, 8 deletions
diff --git a/src/exceptions/ming_bitmap_boundings.php b/src/exceptions/flash_bitmap_boundings.php
index 6cc3414..e649aed 100644
--- a/src/exceptions/ming_bitmap_boundings.php
+++ b/src/exceptions/flash_bitmap_boundings.php
@@ -1,6 +1,6 @@
<?php
/**
* File containing the ezcGraphMingBitmapBoundingsException class
*
* @package Graph
* @version //autogen//
@@ -8,17 +8,17 @@
* @license http://ez.no/licenses/new_bsd New BSD License
*/
/**
* Ming does not support bitmap scaling, so that this exceptions is thrown
* when an image does not have the requested size.
*
* @package Graph
* @version //autogen//
*/
-class ezcGraphMingBitmapBoundingsException extends ezcGraphException
+class ezcGraphFlashBitmapBoundingsException extends ezcGraphException
{
public function __construct( $imageWidth, $imageHeight, $reqWidth, $reqHeight )
{
- parent::__construct( "Ming does not support bitmap scaling, so that it is up to you to scale the image '$imageWidth' * '$imageHeight' to '$reqWidth' * '$reqHeight'." );
+ parent::__construct( "Flash does not support bitmap scaling, so that it is up to you to scale the image '$imageWidth' * '$imageHeight' to '$reqWidth' * '$reqHeight'." );
}
}
@@ -1,6 +1,6 @@
<?php
/**
- * File containing the ezcGraphMingBitmapBoundingsException class
+ * File containing the ezcGraphFlashBitmapBoundingsException class
*
* @package Graph
@@ -8,17 +8,17 @@
*/
/**
- * Ming does not support bitmap scaling, so that this exceptions is thrown
+ * Flash does not support bitmap scaling, so that this exceptions is thrown
* when an image does not have the requested size.
*
diff --git a/src/exceptions/ming_bitmap_type.php b/src/exceptions/flash_bitmap_type.php
index 825a907..d03e9a0 100644
--- a/src/exceptions/ming_bitmap_type.php
+++ b/src/exceptions/flash_bitmap_type.php
@@ -1,6 +1,6 @@
<?php
/**
* File containing the ezcGraphMingBitmapTypeException class
*
* @package Graph
* @version //autogen//
@@ -8,17 +8,17 @@
* @license http://ez.no/licenses/new_bsd New BSD License
*/
/**
* Ming can only read non interlaced bitmaps. This exception is thrown for
* all other image types.
*
* @package Graph
* @version //autogen//
*/
-class ezcGraphMingBitmapTypeException extends ezcGraphException
+class ezcGraphFlashBitmapTypeException extends ezcGraphException
{
public function __construct( $type )
{
- parent::__construct( "Ming can only read non interlaced JPEGs." );
+ parent::__construct( "Flash can only read non interlaced JPEGs." );
}
}
OpenPOWER on IntegriCloud
@@ -1,6 +1,6 @@
<?php
/**
- * File containing the ezcGraphMingBitmapTypeException class
+ * File containing the ezcGraphFlashBitmapTypeException class
*
* @package Graph
@@ -8,17 +8,17 @@
*/
/**
- * Ming can only read non interlaced bitmaps. This exception is thrown for
+ * Flash can only read non interlaced bitmaps. This exception is thrown for
* all other image types.
*